*The following code is used to generate results from
*"Investment Responses to Trade Liberalization: Evidence from U.S. Industries and Establishments"
*by Justin R. Pierce and Peter K. Schott



clear all

**1 Create main dataset, starting with NBER-CES Manufacturing Industry Database and merging in controls
*
*
use naics5811.dta, clear
keep if year>=1990 & year<=2011
rename naics n6
gen k         = cap/piinv
gen rvship    = vship/piship
gen rva       = va/piship

*create ratios and logs of variables
gen lkl       = ln(k/emp)
gen lsl       = ln((emp-prode)/emp)
gen lprod     = ln(prode)
gen lnprod    = ln(emp-prode)
gen lemp      = ln(emp)
gen lh        = ln(prodh)
gen lk        = ln(k)
gen lequip    = ln(equip)
gen lplant    = ln(plant)
gen linvest   = ln(invest/piinv)
gen lrvship   = ln(rvship)
gen lrva      = ln(rva)
gen lrvshipl  = ln(rvship/emp)
gen lrval     = ln(rva/emp)
gen lpiship   = ln(piship)
gen lpiinv    = ln(piinv)

*define globals for merging
global G6  merge m:1 n6       using gap1999_n6                             , keepus(g) 
global G5  merge m:1 n5       using gap1999_n5                             , keepus(g) update
global G4  merge m:1 n4       using gap1999_n4                             , keepus(g) update

global GY6 merge m:1 n6 year  using robustness_ntr_n6_year                 , keepus(n) 
global GY5 merge m:1 n5 year  using robustness_ntr_n5_year                 , keepus(n) update
global GY4 merge m:1 n4 year  using robustness_ntr_n4_year                 , keepus(n) update

global N1  merge m:1 n6       using robustness_matp_n6                     , keepus(atp)
global N2  merge m:1 n6       using robustness_contract_n6                 , keepus(contract)
global N3  merge m:1 n6       using robustness_chinese_subsidy_per_sales_n6, keepus(dsub9805)
global N4  merge m:1 n6       using robustness_chinese_exp_lic_n6          , keepus(se1999)
global N5  merge m:1 n6       using robustness_mfa_twovars_n6_new          , keepus(a*)
global N6  merge m:1 n6       using robustness_union_mem_1990_n6           , keepus(mem1990)
global N7  merge m:1 n6       using robustness_chn_tariff_n6               , keepus(dr)
global N8  merge m:1 n5       using robustness_chn_tariff_n5               , keepus(dr) update
global N9  merge m:1 n4       using robustness_chn_tariff_n4               , keepus(dr) update


gen n5 = int(n6/10)
gen n4 = int(n6/100)
gen n3 = int(n6/1000)

foreach x in G6 G5 G4 {
	display ["`x'"]
	$`x'
	tab _merge
	drop if _merge==2
	drop _merge
}
foreach x in GY6 GY5 GY4 {
	display ["`x'"]
	$`x'
	tab _merge
	drop if _merge==2
	drop _merge
}


*merge RHS variables that vary by naics
foreach x in N1 N2 N3 N4 N5 N6 N7 N8 N9 {
	sort n6
	display ["`x'"]
	$`x'
	tab _merge
	drop if _merge==2
	drop _merge
}
sort n6 year

*create 1990 levels
foreach y in emp rvship rva lkl lsl k {
	foreach x in 1990 {
		gen i         = year==`x'
		gen double t1 = `y'*i
		replace t1=. if ~i
		egen `y'`x'  = max(t1), by(n6)
		drop t1 i
	}
}

*set missing atp and mfa to zero
*
*	atp variable is just 1 for industries with those products, so here set rest to 0
*
*	mfa that don't show up after merge have no covered products, so set to 0
*
foreach x in atp a1994_all a1997_all a2001_all a2004_all ///
			     a1994_row a1997_row a2001_row a2004_row ///
                 a2001_chn a2004_chn{
	replace `x'=0 if `x'==.
}

*sq gap 
gen g2   = g^2

*create post interactions for Equation 2
gen post = year>=2001
foreach z in g g2 lkl1990 lsl1990 contract dr dsub9805 se1999 atp mem1990 n ///
			 a1994_all a1997_all a2001_all a2004_all ///
			 a1994_row a1997_row a2001_row a2004_row ///
             a2001_chn a2004_chn {
	gen `z'_post=`z'*post
}

*gen year interactions for Equation 3
forvalues y=1991(1)2011 {
	gen d`y' = year==`y'
	foreach z in g g2 lkl1990 lsl1990 contract dr dsub9805 se1999 atp mem1990 n ///
			 a1994_all a1997_all a2001_all a2004_all {
		gen d`y'`z' = d`y'*`z'
	}
}

*mfa
gen mfa_all  = (year>1997)*a1997_row + (year>2001)*a2001_all + (year>2004)*a2004_all
save true_reg_public_01_n6, replace




**2 Descriptive figures

**********
*Figure 1: graph investment and employment
**********
local b60 = 1960+(4-1)/12
local b69 = 1969+(12-1)/12
local b73 = 1973+(11-1)/12
local b80 = 1980+(1-1)/12
local b81 = 1981+(7-1)/12
local b90 = 1990+(7-1)/12
local b01 = 2001+(3-1)/12
local b07 = 2007+(12-1)/12

local e60 = 1961+(2-1)/12
local e69 = 1970+(11-1)/12
local e73 = 1975+(3-1)/12
local e80 = 1980+(7-1)/12
local e81 = 1982+(11-1)/12
local e90 = 1991+(3-1)/12
local e01 = 2001+(11-1)/12
local e07 = 2009+(6-1)/12

use naics5811, clear 
replace cap   = cap   /1000
replace equip = equip / 1000
replace plant = plant / 1000
gen rinvest=invest/piinv
collapse (sum) cap equip plant rinvest emp, by(year)
replace rinvest = rinvest/1000
replace emp=emp/1000

local v1 = 20
local v2 = 20
twoway ///
	(scatteri `v1' `b60' `v2' `e60', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b69' `v2' `e69', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b73' `v2' `e73', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b80' `v2' `e80', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b81' `v2' `e81', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b90' `v2' `e90', bcolor(gs15) recast(area) legend(off)) ///
	(scatteri `v1' `b01' `v2' `e01', bcolor(gs15) recast(area) legend(off)) ///
	(scatteri `v1' `b07' `v2' `e07', bcolor(gs15) recast(area) legend(off)) ///
	(scatter rinvest year, ///
		yaxis(2) ///
		c(l l l) ///
		lp(solid) ///
		lc(blue) ///
		lw(medthick) ///
		m(i i i) ///
		xtitle("") ///
		ytitle("USD Billion (Base Year 1997)", axis(2)) ///
	) ///
	(scatter emp year, ///
		yaxis(1) ///
		c(l l l) ///
		lp(dash) ///
		lc(gs8) ///
		lw(medthick) ///
		m(i i i) ///
		xtitle("") ///
		ytitle("Million", axis(1)) ///
	),  ///
	xlabel(1955(10)2015) ///
	title("U.S. Manufacturing Real Investment") ///
	subtitle(1958 to 2011) ///
	legend( ///
		on ///
		rows(1) ///
		order(9 "Employment" 10 "Real Investment") ///
	) 
	


**********
*Figure 2: graph capital stock
**********
local b60 = 1960+(4-1)/12
local b69 = 1969+(12-1)/12
local b73 = 1973+(11-1)/12
local b80 = 1980+(1-1)/12
local b81 = 1981+(7-1)/12
local b90 = 1990+(7-1)/12
local b01 = 2001+(3-1)/12
local b07 = 2007+(12-1)/12

local e60 = 1961+(2-1)/12
local e69 = 1970+(11-1)/12
local e73 = 1975+(3-1)/12
local e80 = 1980+(7-1)/12
local e81 = 1982+(11-1)/12
local e90 = 1991+(3-1)/12
local e01 = 2001+(11-1)/12
local e07 = 2009+(6-1)/12

use naics5811, clear 
replace cap   = cap   /1000
replace equip = equip / 1000
replace plant = plant / 1000
gen rinvest=invest/piinv
collapse (sum) cap equip plant rinvest emp, by(year)
replace rinvest = rinvest/1000
replace emp=emp/1000

local v1 = 2000
local v2 = 2000
twoway ///
	(scatteri `v1' `b60' `v2' `e60', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b69' `v2' `e69', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b73' `v2' `e73', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b80' `v2' `e80', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b81' `v2' `e81', bcolor(gs15) recast(area) legend(off) plotr(m(zero))) ///
	(scatteri `v1' `b90' `v2' `e90', bcolor(gs15) recast(area) legend(off)) ///
	(scatteri `v1' `b01' `v2' `e01', bcolor(gs15) recast(area) legend(off)) ///
	(scatteri `v1' `b07' `v2' `e07', bcolor(gs15) recast(area) legend(off)) ///
	(scatter cap equip plant year, ///
		c(l l l) ///
		lp(solid longdash dash) ///
		lc(red blue green) ///
		lw(medthick medthick medthick) ///
		m(i i i) ///
		xtitle("") ///
		ytitle("USD Billion (Base Year 1997)") ///
	), ///
	xlabel(1955(10)2015) ///
	title("U.S. Manufacturing Real Capital Stock") ///
	subtitle(1958 to 2011) ///
	legend( ///
		on ///
		rows(1) ///
		order(9 "Total Capital Stock" 10 "Equipment" 11 "Structures") ///
	)



**********
*Figure 3
**********
use true_reg_public_01_n6, clear

foreach x in 1990 2000 2007 {
	foreach y in lemp linvest {
		gen double t`y'`x'=.
		replace t`y'`x'=`y' if year==`x'
		egen double `y'`x'=mean(t`y'`x'), by(n6)
	}
}

foreach x in lemp linvest {
	gen double d`x'20002007=`x'2007-`x'2000
	gen double d`x'19902000=`x'2000-`x'1990
}

*Note that the log change is defined for every year for every industry, so  
*scatter should be restricted to any one year
scatter dlemp19902000 dlinvest19902000 if year==1990, ///
	title("1990-2000") ///
	xtitle("Log Change in Investment") ///
	ytitle("Log Change in Employment") ///
|| ///
lfit dlemp19902000 dlinvest19902000 if year==1990, ///
	lp(dash) ///
	lc(gs8) ///
	legend(off) ///
	saving(d9000, replace)


scatter dlemp20002007 dlinvest20002007 if year==1990, ///
	title("2000-2007") ///
	xtitle("Log Change in Investment") ///
	ytitle("Log Change in Employment") ///
|| ///
lfit dlemp20002007 dlinvest20002007 if year==1990, ///
	lp(dash) ///
	lc(gs8) ///
	legend(off) ///
	saving(d0007, replace)


graph combine d9000.gph  d0007.gph, ///
	title("Change in Manufacturing Employment vs Investment") ///
	rows(1) ///
	ycommon ///
	xcommon

	
	
	
	
**********
*Figure 4
**********
use true_reg_public_01_n6, clear

kdensity g if year==2000, ///
	title("Distribution of NTR Gap") ///
	subtitle("Across Six-Digit NAICS Manufacturing Industries") ///
	note("") ///
	xtitle("") ///






*3 Industry-level regressions
*
*
use true_reg_public_01_n6, clear
merge 1:1 n6 year using capital, keepus(fediequip fedistruc)
drop if _merge==2
drop _merge
foreach x in fediequip fedistruc {
	gen double l`x'=ln(`x')
}

sum g if year==2002, det
local own = r(p75)-r(p25)

global GP     g_post
global GPIO   gup3_post gdn3_post
global IP     lkl1990_post lsl1990_post
global OP     contract_post dr_post dsub9805_post se1999_post atp_post mem1990_post mfa_all n 
global NTR    n
global MFA    mfa_all

global AGP     d????g
global AIP     d????lkl1990 d????lsl1990
global AOP     d????contract d????dr d????dsub9805 d????se1999 d????atp d????mem1990
global ANTR    n
global AMFA    mfa_all
global Y       keep if year>=1990 & year<=2011
global W       k1990



$Y
gen i=1
foreach x in linvest lfedistruc lfediequip lk lplant lequip $GP $IP $OP $MFA $NTR {
	replace i=0 if `x'==.
}
egen check = total(i), by(n6)
tab check
*for 1990 to 2011
keep if check==22
*for 1990 to 2007
*keep if check==18
gen ones=1


**********
*Table 2
**********


*Notes:
*linvest is the natural log of total investment
*lfedistruc is the natural log of investment in structures
*lfediequip is the natural log of investment in equipment
capture erase post.txt
foreach yvar in linvest lfedistruc lfediequip {

	reghdfe `yvar' $GP                         [aw=$W] if year<=2007, absorb(n6 year) vce(cluster n6) v(0) fast
	outreg2 using post.txt, append noaster nonote noparen dec(3)

	reghdfe `yvar' $GP $IP                     [aw=$W] if year<=2007, absorb(n6 year) vce(cluster n6) v(0) fast
	outreg2 using post.txt, append noaster nonote noparen dec(3)

	reghdfe `yvar' $GP $IP $OP              [aw=$W] if year<=2007, absorb(n6 year) vce(cluster n6) v(0)  fast
	outreg2 using post.txt, append noaster nonote noparen dec(3)
}

**********
*Table 3
**********

capture erase post.txt
foreach yvar in lk lplant lequip {

	reghdfe `yvar' $GP $IP $OP              [aw=$W] if year<=2007, absorb(n6 year) vce(cluster n6) v(0)  fast
	outreg2 using post.txt, append noaster nonote noparen dec(3)
}



**********************
*Figures 5, 8, 9, 10
**********************

local end = 2007

*Note: Figures can be updated to show years through 2011 by changing local end immediately above
capture erase ann.txt
foreach yvar in linvest lemp lfediequip lfedistruc lk lequip lplant lpiinv  {
	
	if "`yvar'" == "lemp" {
		global W emp1990
		local t = "Employment"
	}

	if "`yvar'" == "linvest" {
		global W k1990
		local t = "Total Investment"
	}
	if "`yvar'" == "lpiinv"  {
		global W k1990
		local t = "Industry Investment Deflators"
		local st = "95% Confidence Interval of Interquartile Shift in Exposure to PNTR"
	}
	if "`yvar'" == "lfediequip"  {
		global W k1990
		local t = "Equipment Investment"
		local st = ""
	}
	if "`yvar'" == "lfedistruc"  {
		global W k1990
		local t = "Structures Investment"
		local st = ""
	}

	if "`yvar'" == "lk"  {
		global W k1990
		local t = "Total Capital Stock"
	}
	if "`yvar'" == "lplant"  {
		global W k1990
		local t = "Structures Capital Stock"
		local st = ""
	}
	if "`yvar'" == "lequip"  {
		global W k1990
		local t = "Equipment Capital Stock"
		local st = ""
	}
	
	
	
	
	reghdfe `yvar' $AGP $AIP $AOP $ANTR $AMFA [aw=$W], absorb(n6 year) vce(cluster n6) v(0) fast
	outreg2 using ann.txt, append aster nonote noparen dec(3)

		lincom d1991g * `own' 
		mat p1 = (r(estimate), r(se), r(df)) 
		forvalues y=1992(1)`end' {
			lincom d`y'g * `own'
			mat p1 = p1 \ (r(estimate), r(se), r(df)) 
		}
	

	preserve
		
		*save the linear combinations as a dataset
		matlist p1
		svmat double p1
		keep p11 p12 p13
		drop if p11==.
		egen year = seq()
		replace year=year+1990
		replace p11 = . if p11==0
		replace p12 = . if p12==0
		gen clo = p11 - 1.96 * p12
		gen chi = p11 + 1.96 * p12
   		save fig_ann_`yvar', replace			

		*figure: both conditional and unconditional together
		*local yvar = "lpiinv"
		
		use fig_ann_`yvar', clear
		
		*figure: just full spec
		twoway ///
			rarea clo chi year, ///
				title("`t'") ///
				subtitle("`st'") ///
				legend(off) ///
				m(i i) ///
				xtitle("") ///
				ytitle("") ///
				lcol(gs9) ///
				fcol(gs9)  ///
				yline(0, lp(dash) lc(gs0) ) ///
				xline(2000, lp(dash) lc(gs0) ) ///
				xlabel(1991(4)2011) ///
				saving(f`yvar'0, replace)

		graph export fig_ann_`yvar'.png, replace		
		
	restore
}

graph combine flk0.gph flequip0.gph flplant0.gph, ///
	title("Estimated Industry-Level Impact of Interquartile Shift in Exposure to PNTR") ///
	subtitle("95 Percent Confidence Intervals") ///
	rows(1) ///
	xsize(10) ///
	iscale(*1.25) ///
	ycommon 

graph combine flinvest0.gph flemp0.gph, ///
	title("Estimated Industry-Level Impact of Interquartile Shift in Exposure to PNTR") ///
	subtitle("95 Percent Confidence Intervals") ///
	rows(1) ///
	xsize(10) ///
	iscale(*1.25) ///
	ycommon 

graph combine flinvest0.gph flemp0.gph flfediequip0.gph flfedistruc0.gph, ///
	title("Estimated Impact of Interquartile Shift in Exposure to PNTR") ///
	subtitle("95 Percent Confidence Intervals") ///
	rows(2) ///
	xsize(10) ///
	ysize(7) ///
	iscale(*1) ///
	ycommon 








